@@ -1,8 +1,8 @@
 """
-Sphinx拡張
-
+sphinxcontrib.kana_text
+=======================
 参考情報
-
+--------
 - https://www.sphinx-doc.org/ja/master/usage/restructuredtext/basics.html
 - https://www.sphinx-doc.org/ja/master/development/tutorials/helloworld.html
 
@@ -232,9 +232,9 @@ latexの関連情報
 """
 
 __copyright__ = 'Copyright (C) 2021 @koKkekoh'
-__license__ = 'BSD' #BSD 2-Clause License
+__license__ = 'BSD 2-Clause License'
 __author__  = '@koKekkoh'
-__version__ = '0.17.5' #2021.09.27
+__version__ = '0.18.1.1'
 __url__     = 'https://qiita.com/tags/sphinxcotrib.kana_text'
 
 import re
@@ -437,7 +437,7 @@ class _KanaText(Text):
                 ruby = [(True, (word, kana))]
             elif onoff == 'specific': #細かくルビの表示/非表示を指定する
                 #アレコレがんばる
-                ruby, opt, s_t, end_r, s_r, end_r = [], list(option), 0, 0, 0, 0
+                ruby, opt, s_t, end_t, s_r, end_r = [], list(option), 0, 0, 0, 0
                 for o in opt:
                     if not word[s_t:] or not kana[s_r:]: #文字がない
                         break
